#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5 import QtWidgets
from PyQt5.QtWidgets import QWizardPage
from PyQt5.QtCore import QDir, pyqtSignal

from common.regexes import checkRegexLastPath
from common.logger import logVar, logMsg

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Page2(QWizardPage):
    
    # signal: used to return values as the gui is used
    sig_string = pyqtSignal(str)
    
    def __init__(self, parent=None):
        super(Page2, self).__init__(parent)

        # attributes
        self.folder_selection = {"path": "", "valid": False}

        # headers
        self.setTitle("Sélection")

        # layout
        verticalLayout = QtWidgets.QVBoxLayout()
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        
        # button2
        self.oneDirButton = QtWidgets.QPushButton()
        self.oneDirButton.setObjectName("oneDirButton")
        self.oneDirButton.setText("Dossier...")
        self.oneDirButton.clicked.connect(lambda: Page2.pick_folder(self,oneLabel,"OneDrive")) #lambda so func is not directly run
        self.gridLayout_2.addWidget(self.oneDirButton, 0, 1, 1, 1)
        
        # label prompt
        self.oneDirLabel = QtWidgets.QLabel()
        self.oneDirLabel.setObjectName("oneDirLabel")
        self.oneDirLabel.setText("Pointez le dossier à scanner:")
        self.gridLayout_2.addWidget(self.oneDirLabel, 0, 0, 1, 1)
        verticalLayout.addLayout(self.gridLayout_2)
        
        # label for oneDrivePATH
        global oneLabel
        oneLabel = QtWidgets.QLabel()
        oneLabel.setObjectName("oneLabel")
        oneLabel.setText("")
        oneLabel.setWordWrap(True)
        verticalLayout.addWidget(oneLabel)

        # set layout
        self.setLayout(verticalLayout)

    # function to choose folder
    def pick_folder(self,lbl,pattern):
        
        # set folder to open prompt on
        from os.path import expanduser #home path
        home = expanduser("~")
        
        # open file select dialog
        dialog = QtWidgets.QFileDialog()
        fname = dialog.getExistingDirectory(None, "Choisir un dossier", home)
        
        # get path
        if fname:
            fname = QDir.toNativeSeparators(fname)
            # assign to self variable
            self.folder_selection["path"] = fname
            # set valid for isComplete
            self.folder_selection["valid"] = True
            # update GUI text
            lbl.setText(fname)
        else:
            # reset if fname empty
            self.folder_selection["path"] = ""
            self.folder_selection["valid"] = False
            lbl.setText(fname)
        
        # update isComplete
        self.completeChanged.emit()

        # log it
        logVar("folder_selection", self.folder_selection)

        # send signal to functions for gui update
        self.sig_string.emit(self.folder_selection['path'])

    # prevent Continue button until mandatories are set
    def isComplete(self):
        if self.folder_selection["valid"] == True:
            return True
        else:
            return False

    #-------------------------------------------------
    # initializePage
    #-------------------------------------------------

    # on page opening
    def initializePage(self):
        logMsg("PAGE", "2")