#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5 import QtWidgets
from PyQt5.QtWidgets import QWizardPage
from PyQt5.QtCore import QThread, pyqtSignal

from common.logger import logVar, logMsg
from workers import worker1, worker2, worker4

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Page3(QWizardPage):

    # signal: used to force next page once thread finished
    sig_next = pyqtSignal()

    def __init__(self, filesPaths, parent=None):
        super(Page3, self).__init__(parent)
        
        # attributes
        self.indexFilePath = filesPaths[0]
        self.renameFilePath = filesPaths[1]
        self.renameUniqueFilePath = filesPaths[2]
        self.renameConflictsFilePath = filesPaths[3]

        #headers
        self.setTitle("Recherche des caractères")

        #progress bar
        self.progress_bar = QtWidgets.QProgressBar(self)

        #label: current state of process
        self.progress_label = QtWidgets.QLabel()
        self.progress_label.setWordWrap(True)

        #layout
        self.layout = QtWidgets.QVBoxLayout()
        self.layout.addWidget(self.progress_bar)
        self.layout.addWidget(self.progress_label)
        self.setLayout(self.layout)

    # function just to receive value from page2 signal
    def updatePath(self, sig):
        self.oneDrivePath = sig

    
    #-------------------------------------------------
    # THREADS
    #-------------------------------------------------

    # thread for index
    def index_thread(self):
        
        # instance thread & worker
        self.thread = QThread(parent=self)
        self.worker1 = worker1.Worker1(self.oneDrivePath, self.indexFilePath)
        # assign worker to thread
        self.worker1.moveToThread(self.thread)

        # signals progress_bar<->worker
        self.worker1.sig_string.connect(self.labelProgress)
        self.worker1.sig_progress.connect(self.updateProgress)
        self.worker1.sig_maxProgress.connect(self.setMaxProgress)
        self.worker1.sig_workerEnd.connect(self.index_sig_end)

        # connect and start thread
        self.thread.started.connect(self.worker1.makeIndex)
        self.thread.start()

    # thread for regex
    def regex_thread(self):
        
        # instance thread & worker
        self.thread = QThread(parent=self)
        self.worker2 = worker2.Worker2(self.indexFilePath, self.renameFilePath)
        # assign worker to thread
        self.worker2.moveToThread(self.thread)

        # signals progress_bar<->worker
        self.worker2.sig_string.connect(self.labelProgress)
        self.worker2.sig_progress.connect(self.updateProgress)
        self.worker2.sig_maxProgress.connect(self.setMaxProgress)
        self.worker2.sig_workerEnd.connect(self.regex_sig_end)

        # connect and start thread
        self.thread.started.connect(self.worker2.searchForbidden)
        self.thread.start()

    # thread for renameFile spit in renameUnique & renameConflict
    def conflict_thread(self):
        
        # instance thread & worker
        self.thread = QThread(parent=self)
        self.worker4 = worker4.Worker4(self.indexFilePath, self.renameFilePath, self.renameUniqueFilePath, self.renameConflictsFilePath)
        
        # assign worker to thread
        self.worker4.moveToThread(self.thread)

        # signals progress_bar<->worker
        self.worker4.sig_string.connect(self.labelProgress)
        self.worker4.sig_progress.connect(self.updateProgress)
        self.worker4.sig_maxProgress.connect(self.setMaxProgress)
        self.worker4.sig_workerEnd.connect(self.conflict_sig_end)

        # connect and start thread
        self.thread.started.connect(self.worker4.makeFiltered)
        self.thread.start()

    #-------------------------------------------------
    # SIGNAL PROCESSING
    #-------------------------------------------------

    # signal processing (same for all workers)
    def labelProgress(self, sig):
        self.progress_label.setText(sig)
    def updateProgress(self, sig):
        self.progress_bar.setValue(sig)
    def setMaxProgress(self, sig):
        self.progress_bar.setMaximum(sig)

    # signal processing (different for workers)
    # index thread end
    def index_sig_end(self):        
        # close thread and log
        self.thread.quit()
        logMsg("INFO", "Index thread closed.")
        # run next thread
        self.regex_thread()
        self.thread.start()

    # regex thread end
    def regex_sig_end(self):
        # close thread and log
        self.thread.quit()
        logMsg("INFO", "Regex thread closed.")
        # run next thread
        self.conflict_thread()
        self.thread.start()

    # conflict thread end
    def conflict_sig_end(self):
        # close thread and log
        self.thread.quit()
        logMsg("INFO", "Conflict thread closed.")
        # signal to QWizardPage to go next page
        self.sig_next.emit()

    #-------------------------------------------------
    # initializePage
    #-------------------------------------------------

    # on page opening
    def initializePage(self):

        # log arrival on page
        logMsg("PAGE", "3")

        # run thread for indexing
        self.index_thread()
