#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5 import QtWidgets
from PyQt5.QtWidgets import QWizard, QWizardPage, QScrollArea
from PyQt5.QtCore import pyqtSignal
import csv

from common.logger import logMsg
from common.scrollLabel import ScrollLabel

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Page4(QWizardPage):

    # signal: used to define next page depending if renaming needed or not
    sig_next = pyqtSignal()

    def __init__(self, filesPaths, parent=None):
        super(Page4, self).__init__(parent)

        # attributes
        self.renameFilePath = filesPaths[1]
        self.renameUniqueFilePath = filesPaths[2]
        self.renameConflictsFilePath = filesPaths[3]

        # headers
        self.setTitle("Les modifications suivantes seront apportées:")

        # label
        self.scroll1 = ScrollLabel()
        self.scroll1.setText("ERROR 01: merci de contacter le helpdesk.")

        # layout
        layout = QtWidgets.QVBoxLayout()
        layout.addWidget(self.scroll1)
        self.setLayout(layout)
        

    # function just to receive value from page2 signal
    def updatePath(self, sig):
        self.oneDrivePath = sig

    #-------------------------------------------------
    # initializePage
    #-------------------------------------------------

    # on page opening
    def initializePage(self):
        
        # log
        logMsg("PAGE", "4")

        # read renameFile
        self.renameUniqueFile = open(self.renameUniqueFilePath, "r")

        # check if not empty
        if self.renameUniqueFile.read(1):
            
            # log
            logMsg("INFO", "renameUniqueFile is not empty.")
            
            # commit page = no return possible
            self.setCommitPage(True)
            self.setButtonText(QWizard.CommitButton, "Valider")
        
            # restart pointer at line 0 for the loop
            self.renameUniqueFile.seek(0)
            
            # realtive file content in the scrollLabel
            dataReader = csv.reader(self.renameUniqueFile, delimiter="\t")
            content = ""
            count = 0

            # clean csv content
            for column in dataReader:
                
                # absolute to relative path
                leftColumn = column[0].replace(self.oneDrivePath, '. ')
                rightColumn = column[1].replace(self.oneDrivePath, '. ')
                
                # count
                count += 1

                # set
                lineSeparator = "Renommage " + str(count) + ":\n"
                lineRename = leftColumn + "\n" + rightColumn + "\n\n"
                
                # assemble
                content = content + lineSeparator + lineRename

            # assign it to scroll label
            self.scroll1.setText(content)
        
        # if empty
        else:
            
            # log
            logMsg("INFO", self.renameFilePath + " is empty.")
            logMsg("INFO", "Renaming skipped.")
            
            # emit signal to wizard
            self.sig_next.emit()
            
            # error msg if page not skipped
            self.scroll1.setText("Aucun caractère interdit trouvé.\n"
                                 "Pas de fichier ou de dossier à renommer.")

        # close renameFile
        self.renameUniqueFile.close()
