#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5 import QtWidgets
from PyQt5.QtWidgets import QWizardPage
from PyQt5.QtCore import QThread, pyqtSignal

from common.logger import logMsg
from workers import worker3

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Page5(QWizardPage):

    # signal: used to force next page once thread finished
    sig_next = pyqtSignal()

    def __init__(self, filesPaths, parent=None):
        super(Page5, self).__init__(parent)
        
        # attributes
        self.renameUniqueFilePath = filesPaths[2]

        # headers
        self.setTitle("Remplacement des caractères interdits")

        #progress bar
        self.progress_bar = QtWidgets.QProgressBar(self)

        #label: current state of process
        self.progress_label = QtWidgets.QLabel()
        self.progress_label.setWordWrap(True)

        #layout
        self.layout = QtWidgets.QVBoxLayout()
        self.layout.addWidget(self.progress_bar)
        self.layout.addWidget(self.progress_label)
        self.setLayout(self.layout)
        

    #-------------------------------------------------
    # THREADS
    #-------------------------------------------------

    # thread for index
    def rename_thread(self):
        
        # instance thread & worker
        self.thread = QThread(parent=self)
        self.worker3 = worker3.Worker3(self.renameUniqueFilePath)
        # assign worker to thread
        self.worker3.moveToThread(self.thread)

        # signals progress_bar<->worker
        self.worker3.sig_progress.connect(self.updateProgress)
        self.worker3.sig_maxProgress.connect(self.setMaxProgress)
        self.worker3.sig_workerEnd.connect(self.sig_end)

        # connect and start thread
        self.thread.started.connect(self.worker3.renaming)
        self.thread.start()

    #-------------------------------------------------
    # SIGNAL PROCESSING
    #-------------------------------------------------

    #
    def test_strSig(self, sig):
        self.progress_label.setText(sig)
    #
    def updateProgress(self, sig):
        self.progress_bar.setValue(sig)
    #
    def setMaxProgress(self, sig):
        self.progress_bar.setMaximum(sig)
    #
    def sig_end(self):        
        # close thread and log
        self.thread.quit()
        logMsg("INFO", "Rename thread closed.")
        # signal to QWizardPage to go next page
        self.sig_next.emit()

    #-------------------------------------------------
    # initializePage
    #-------------------------------------------------

    # on page opening
    def initializePage(self):
        
        # log
        logMsg("PAGE", "5")

        # run thread for indexing
        self.rename_thread()