#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5.QtCore import QObject, pyqtSignal
import re
from time import sleep

from common.logger import logMsg

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Worker2(QObject):
    
    # signals
    sig_string = pyqtSignal(str)
    sig_progress = pyqtSignal(int)
    sig_maxProgress = pyqtSignal(int)
    sig_workerEnd = pyqtSignal()

    #
    def __init__(self, indexFilePath, renameFilePath, parent=None):
        QObject.__init__(self, parent)
        
        # attributes
        self.indexFilePath = indexFilePath
        self.renameFilePath = renameFilePath

    # Search for forbidden characters
    def searchForbidden(self):

        # set sigs
        self.sig_progress.emit(0)
        self.sig_maxProgress.emit(0)
        self.sig_string.emit("Recherche des caractères interdits...")
        
        # log
        logMsg("INFO", "searchForbidden START")

        # sleep to make it slow - userfriendly
        sleep(0.5)

        # read indexFile, append renameFile
        self.indexFile = open(self.indexFilePath, "r")
        self.renameFile = open(self.renameFilePath, "w")

        # read index and send nb of lines
        lines = self.indexFile.readlines()
        self.sig_maxProgress.emit(len(lines))

        # vars for loop
        count = 0
        reg_forbidenChars = r"[\"]|[\*]|[:]|[<]|[>]|[\?]|[\\]|[|]"
        reg_spacesNdots = r"^[ \t]+|[ \t]+$|\.+$"
        allConflictsReg = reg_forbidenChars + "|" + reg_spacesNdots

        # start of loop
        for line in lines:

            # divide in 'path/' '/element' to modify only the latter
            linePath = re.compile("^.*/").search(line).group()
            lineName = re.compile("/[^/]*$").search(line).group()
            # remove lead slash in name
            lineName = lineName[1:]

            # check if lineName matches any conflict
            if re.compile(allConflictsReg).search(lineName):

                # (A) forbiden chars
                newLineName = re.sub(reg_forbidenChars,"_",lineName)

                # (B) loop until thers's no trail/head space/dot
                while re.compile(reg_spacesNdots).search(newLineName):
                        newLineName = re.sub(reg_spacesNdots,"",newLineName)

                # write line for renameFile (with absolute path)
                line = line.strip('\n')
                renameLine = line + "\t" + linePath + newLineName
                self.renameFile.write(renameLine)

            # increment to keep track of progress
            count+=1
            self.sig_progress.emit(count)

        # close files
        self.indexFile.close()
        self.renameFile.close()

        # log
        logMsg("INFO", "total forbidden found: " + str(count))
        logMsg("INFO", "searchForbidden END")

        # end sig
        self.sig_progress.emit(1)
        self.sig_maxProgress.emit(1)
        self.sig_workerEnd.emit()
 