#!/usr/bin/env python3
# -*- coding: utf-8 -*- 

#-------------------------------------------------
# IMPORTS
#-------------------------------------------------

from PyQt5.QtCore import QObject, pyqtSignal
from time import sleep

from common.logger import logMsg

#-------------------------------------------------
# MODULES
#-------------------------------------------------

class Worker4(QObject):
    
    # signals
    sig_string = pyqtSignal(str)
    sig_progress = pyqtSignal(int)
    sig_maxProgress = pyqtSignal(int)
    sig_workerEnd = pyqtSignal()

    #
    def __init__(self, indexFilePath, renameFilePath, renameUniqueFilePath, renameConflictsFilePath, parent=None):
        QObject.__init__(self, parent)
        
        # attributes
        self.indexFilePath = indexFilePath
        self.renameFilePath = renameFilePath
        self.renameUniqueFilePath = renameUniqueFilePath
        self.renameConflictsFilePath = renameConflictsFilePath

    # Search for forbidden characters
    def makeFiltered(self):

        # set sigs
        self.sig_progress.emit(0)
        self.sig_maxProgress.emit(0)
        self.sig_string.emit("Vérification des conflits...")
        
        # log
        logMsg("INFO", "makeFiltered START")

        # sleep to make it slow - userfriendly
        sleep(0.5)

        # read renameFile
        self.renameFile = open(self.renameFilePath, "r")
        # assign content to var
        self.renameLines = self.renameFile.readlines()
        # set maxProgress to var length
        self.sig_maxProgress.emit(len(self.renameLines))
        
        # write filtered files
        self.renameUniqueFile = open(self.renameUniqueFilePath, "w")
        self.renameConflictsFile = open(self.renameConflictsFilePath, "w")
        
        # vars for the loop
        seen = set()
        conflicts = []
        nbRow = 0

        # conflicts search 1: add all original path in seen (impossible to have duplicates)
        self.indexFile = open(self.indexFilePath, "r")
        self.indexLines = self.indexFile.readlines()
        for line in self.indexLines:
                seen.add(line)
        self.indexFile.close()

        # conflicts search 2: loop through renamed paths (and deal with duplicates)
        for row in self.renameLines:
                
                # instead of csv.reader(file, delimiter="\t")
                column = row.split('\t')
                
                # check if column[1] was already seen
                if column[1] in seen:
                        # add to conflicts
                        conflicts.append(column[1])
                # else it's the first occurence
                else:
                        # add to seen list
                        seen.add(column[1])
                # progress
                nbRow += 1
                self.sig_progress.emit(nbRow)

        # remove duplicates in list
        conflicts = list(dict.fromkeys(conflicts))

        # reset pointer
        self.renameFile.seek(0)
        nbRow = 0

        # conflicts process: diviser en unique ou conflit
        for row in self.renameFile:
                # instead of csv.reader(file, delimiter="\t")
                column = row.split('\t')

                # divide in separate files if matches conflict
                if column[1] in conflicts:
                        self.renameConflictsFile.write(row)
                else:
                        self.renameUniqueFile.write(row)
                # progress
                nbRow += 1
                self.sig_progress.emit(nbRow)

        #log
        logMsg("INFO", "Conflicts completed: " + str(len(conflicts)) + " conflicts found.")

        # close files
        self.renameFile.close()
        self.renameUniqueFile.close()
        self.renameConflictsFile.close()

        # sleep to make it slow - userfriendly
        sleep(0.5)

        # log
        logMsg("INFO", "makeFiltered END")

        # end sig
        self.sig_progress.emit(1)
        self.sig_maxProgress.emit(1)
        self.sig_workerEnd.emit()
 